@@ -31,8 +31,7 @@ sys.path.insert(0, os.path.abspath('./'))
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
 extensions = [
-    'oslo_config.sphinxconfiggen',
-    'oslosphinx',
+    'oslo_config.sphinxext',
     'sphinx.ext.autodoc',
     'sphinx.ext.viewcode',
     'sphinxcontrib.httpdomain',
@@ -41,10 +40,14 @@ extensions = [
     'wsmeext.sphinxext',
     'ext.term',
     'ext.versioned_notifications',
+    'oslo_config.sphinxconfiggen',
+    'openstackdocstheme',
 ]
 
 wsme_protocols = ['restjson']
-config_generator_config_file = '../../etc/watcher/watcher-config-generator.conf'
+config_generator_config_file = [(
+    '../../etc/watcher/oslo-config-generator/watcher.conf',
+    '_static/watcher')]
 sample_config_basename = 'watcher'
 
 # autodoc generation is a bit aggressive and a nuisance when doing heavy
@@ -92,6 +95,8 @@ add_function_parentheses = True
 # unit titles (such as .. function::).
 add_module_names = True
 
+suppress_warnings = ['app.add_directive']
+
 # The name of the Pygments (syntax highlighting) style to use.
 pygments_style = 'sphinx'
 
@@ -117,12 +122,20 @@ man_pages = [
 # Sphinx are currently 'default' and 'sphinxdoc'.
 # html_theme_path = ["."]
 # html_theme = '_theme'
+html_theme = 'openstackdocs'
 # html_static_path = ['static']
-html_theme_options = {'incubating': True}
+# html_theme_options = {}
 
 # Output file base name for HTML help builder.
 htmlhelp_basename = '%sdoc' % project
 
+html_last_updated_fmt = '%Y-%m-%d %H:%M'
+
+#openstackdocstheme options
+repository_name = 'openstack/watcher'
+bug_project = 'watcher'
+bug_tag = ''
+
 # Grouping the document tree into LaTeX files. List of tuples
 # (source start file, target name, title, author, documentclass
 # [howto/manual]).
