@@ -17,9 +17,6 @@
 # limitations under the License.
 #
 
-import six
-import voluptuous
-
 from watcher._i18n import _
 from watcher.applier.actions import base
 from watcher.common import exception
@@ -51,15 +48,24 @@ class ChangeNovaServiceState(base.BaseAction):
 
     @property
     def schema(self):
-        return voluptuous.Schema({
-            voluptuous.Required(self.RESOURCE_ID):
-                voluptuous.All(
-                    voluptuous.Any(*six.string_types),
-                    voluptuous.Length(min=1)),
-            voluptuous.Required(self.STATE):
-                voluptuous.Any(*[state.value
-                                 for state in list(element.ServiceState)]),
-        })
+        return {
+            'type': 'object',
+            'properties': {
+                'resource_id': {
+                    'type': 'string',
+                    "minlength": 1
+                },
+                'state': {
+                    'type': 'string',
+                    'enum': [element.ServiceState.ONLINE.value,
+                             element.ServiceState.OFFLINE.value,
+                             element.ServiceState.ENABLED.value,
+                             element.ServiceState.DISABLED.value]
+                }
+            },
+            'required': ['resource_id', 'state'],
+            'additionalProperties': False,
+        }
 
     @property
     def host(self):
