@@ -21,6 +21,9 @@ ServerConsolidation = goals.ServerConsolidation
 ThermalOptimization = goals.ThermalOptimization
 Unclassified = goals.Unclassified
 WorkloadBalancing = goals.WorkloadBalancing
+NoisyNeighbor = goals.NoisyNeighborOptimization
+SavingEnergy = goals.SavingEnergy
 
 __all__ = ("Dummy", "ServerConsolidation", "ThermalOptimization",
-           "Unclassified", "WorkloadBalancing", )
+           "Unclassified", "WorkloadBalancing",
+           "NoisyNeighborOptimization", "SavingEnergy")
