@@ -17,8 +17,6 @@
 # limitations under the License.
 
 from oslo_log import log
-
-from watcher._i18n import _LI, _LW
 from watcher.common import exception
 from watcher.common import nova_helper
 from watcher.decision_engine.model import element
@@ -45,8 +43,8 @@ class NovaNotification(base.NotificationEndpoint):
             if node_uuid:
                 self.get_or_create_node(node_uuid)
         except exception.ComputeNodeNotFound:
-            LOG.warning(_LW("Could not find compute node %(node)s for "
-                            "instance %(instance)s"),
+            LOG.warning("Could not find compute node %(node)s for "
+                        "instance %(instance)s",
                         dict(node=node_uuid, instance=instance_uuid))
         try:
             instance = self.cluster_data_model.get_instance_by_uuid(
@@ -67,6 +65,7 @@ class NovaNotification(base.NotificationEndpoint):
         memory_mb = instance_flavor_data['memory_mb']
         num_cores = instance_flavor_data['vcpus']
         disk_gb = instance_flavor_data['root_gb']
+        instance_metadata = data['nova_object.data']['metadata']
 
         instance.update({
             'state': instance_data['state'],
@@ -76,6 +75,7 @@ class NovaNotification(base.NotificationEndpoint):
             'vcpus': num_cores,
             'disk': disk_gb,
             'disk_capacity': disk_gb,
+            'metadata': instance_metadata,
         })
 
         try:
@@ -91,6 +91,7 @@ class NovaNotification(base.NotificationEndpoint):
         memory_mb = data['memory_mb']
         num_cores = data['vcpus']
         disk_gb = data['root_gb']
+        instance_metadata = data['metadata']
 
         instance.update({
             'state': data['state'],
@@ -100,6 +101,7 @@ class NovaNotification(base.NotificationEndpoint):
             'vcpus': num_cores,
             'disk': disk_gb,
             'disk_capacity': disk_gb,
+            'metadata': instance_metadata,
         })
 
         try:
@@ -198,18 +200,18 @@ class NovaNotification(base.NotificationEndpoint):
         try:
             self.cluster_data_model.delete_instance(instance, node)
         except Exception:
-            LOG.info(_LI("Instance %s already deleted"), instance.uuid)
+            LOG.info("Instance %s already deleted", instance.uuid)
 
 
-class VersionnedNotificationEndpoint(NovaNotification):
+class VersionedNotificationEndpoint(NovaNotification):
     publisher_id_regex = r'^nova-compute.*'
 
 
-class UnversionnedNotificationEndpoint(NovaNotification):
+class UnversionedNotificationEndpoint(NovaNotification):
     publisher_id_regex = r'^compute.*'
 
 
-class ServiceUpdated(VersionnedNotificationEndpoint):
+class ServiceUpdated(VersionedNotificationEndpoint):
 
     @property
     def filter_rule(self):
@@ -220,8 +222,10 @@ class ServiceUpdated(VersionnedNotificationEndpoint):
         )
 
     def info(self, ctxt, publisher_id, event_type, payload, metadata):
-        LOG.info(_LI("Event '%(event)s' received from %(publisher)s "
-                     "with metadata %(metadata)s") %
+        ctxt.request_id = metadata['message_id']
+        ctxt.project_domain = event_type
+        LOG.info("Event '%(event)s' received from %(publisher)s "
+                 "with metadata %(metadata)s" %
                  dict(event=event_type,
                       publisher=publisher_id,
                       metadata=metadata))
@@ -235,7 +239,7 @@ class ServiceUpdated(VersionnedNotificationEndpoint):
             LOG.exception(exc)
 
 
-class InstanceCreated(VersionnedNotificationEndpoint):
+class InstanceCreated(VersionedNotificationEndpoint):
 
     @property
     def filter_rule(self):
@@ -262,14 +266,15 @@ class InstanceCreated(VersionnedNotificationEndpoint):
         )
 
     def info(self, ctxt, publisher_id, event_type, payload, metadata):
-        LOG.info(_LI("Event '%(event)s' received from %(publisher)s "
-                     "with metadata %(metadata)s") %
+        ctxt.request_id = metadata['message_id']
+        ctxt.project_domain = event_type
+        LOG.info("Event '%(event)s' received from %(publisher)s "
+                 "with metadata %(metadata)s" %
                  dict(event=event_type,
                       publisher=publisher_id,
                       metadata=metadata))
         LOG.debug(payload)
         instance_data = payload['nova_object.data']
-
         instance_uuid = instance_data['uuid']
         node_uuid = instance_data.get('host')
         instance = self.get_or_create_instance(instance_uuid, node_uuid)
@@ -277,7 +282,7 @@ class InstanceCreated(VersionnedNotificationEndpoint):
         self.update_instance(instance, payload)
 
 
-class InstanceUpdated(VersionnedNotificationEndpoint):
+class InstanceUpdated(VersionedNotificationEndpoint):
 
     @staticmethod
     def _match_not_new_instance_state(data):
@@ -296,8 +301,10 @@ class InstanceUpdated(VersionnedNotificationEndpoint):
         )
 
     def info(self, ctxt, publisher_id, event_type, payload, metadata):
-        LOG.info(_LI("Event '%(event)s' received from %(publisher)s "
-                     "with metadata %(metadata)s") %
+        ctxt.request_id = metadata['message_id']
+        ctxt.project_domain = event_type
+        LOG.info("Event '%(event)s' received from %(publisher)s "
+                 "with metadata %(metadata)s" %
                  dict(event=event_type,
                       publisher=publisher_id,
                       metadata=metadata))
@@ -310,7 +317,7 @@ class InstanceUpdated(VersionnedNotificationEndpoint):
         self.update_instance(instance, payload)
 
 
-class InstanceDeletedEnd(VersionnedNotificationEndpoint):
+class InstanceDeletedEnd(VersionedNotificationEndpoint):
 
     @property
     def filter_rule(self):
@@ -321,8 +328,10 @@ class InstanceDeletedEnd(VersionnedNotificationEndpoint):
         )
 
     def info(self, ctxt, publisher_id, event_type, payload, metadata):
-        LOG.info(_LI("Event '%(event)s' received from %(publisher)s "
-                     "with metadata %(metadata)s") %
+        ctxt.request_id = metadata['message_id']
+        ctxt.project_domain = event_type
+        LOG.info("Event '%(event)s' received from %(publisher)s "
+                 "with metadata %(metadata)s" %
                  dict(event=event_type,
                       publisher=publisher_id,
                       metadata=metadata))
@@ -343,7 +352,7 @@ class InstanceDeletedEnd(VersionnedNotificationEndpoint):
         self.delete_instance(instance, node)
 
 
-class LegacyInstanceUpdated(UnversionnedNotificationEndpoint):
+class LegacyInstanceUpdated(UnversionedNotificationEndpoint):
 
     @property
     def filter_rule(self):
@@ -354,8 +363,10 @@ class LegacyInstanceUpdated(UnversionnedNotificationEndpoint):
         )
 
     def info(self, ctxt, publisher_id, event_type, payload, metadata):
-        LOG.info(_LI("Event '%(event)s' received from %(publisher)s "
-                     "with metadata %(metadata)s") %
+        ctxt.request_id = metadata['message_id']
+        ctxt.project_domain = event_type
+        LOG.info("Event '%(event)s' received from %(publisher)s "
+                 "with metadata %(metadata)s" %
                  dict(event=event_type,
                       publisher=publisher_id,
                       metadata=metadata))
@@ -368,7 +379,7 @@ class LegacyInstanceUpdated(UnversionnedNotificationEndpoint):
         self.legacy_update_instance(instance, payload)
 
 
-class LegacyInstanceCreatedEnd(UnversionnedNotificationEndpoint):
+class LegacyInstanceCreatedEnd(UnversionedNotificationEndpoint):
 
     @property
     def filter_rule(self):
@@ -379,8 +390,10 @@ class LegacyInstanceCreatedEnd(UnversionnedNotificationEndpoint):
         )
 
     def info(self, ctxt, publisher_id, event_type, payload, metadata):
-        LOG.info(_LI("Event '%(event)s' received from %(publisher)s "
-                     "with metadata %(metadata)s") %
+        ctxt.request_id = metadata['message_id']
+        ctxt.project_domain = event_type
+        LOG.info("Event '%(event)s' received from %(publisher)s "
+                 "with metadata %(metadata)s" %
                  dict(event=event_type,
                       publisher=publisher_id,
                       metadata=metadata))
@@ -393,7 +406,7 @@ class LegacyInstanceCreatedEnd(UnversionnedNotificationEndpoint):
         self.legacy_update_instance(instance, payload)
 
 
-class LegacyInstanceDeletedEnd(UnversionnedNotificationEndpoint):
+class LegacyInstanceDeletedEnd(UnversionedNotificationEndpoint):
 
     @property
     def filter_rule(self):
@@ -404,8 +417,10 @@ class LegacyInstanceDeletedEnd(UnversionnedNotificationEndpoint):
         )
 
     def info(self, ctxt, publisher_id, event_type, payload, metadata):
-        LOG.info(_LI("Event '%(event)s' received from %(publisher)s "
-                     "with metadata %(metadata)s") %
+        ctxt.request_id = metadata['message_id']
+        ctxt.project_domain = event_type
+        LOG.info("Event '%(event)s' received from %(publisher)s "
+                 "with metadata %(metadata)s" %
                  dict(event=event_type,
                       publisher=publisher_id,
                       metadata=metadata))
@@ -424,7 +439,7 @@ class LegacyInstanceDeletedEnd(UnversionnedNotificationEndpoint):
         self.delete_instance(instance, node)
 
 
-class LegacyLiveMigratedEnd(UnversionnedNotificationEndpoint):
+class LegacyLiveMigratedEnd(UnversionedNotificationEndpoint):
 
     @property
     def filter_rule(self):
@@ -435,8 +450,10 @@ class LegacyLiveMigratedEnd(UnversionnedNotificationEndpoint):
         )
 
     def info(self, ctxt, publisher_id, event_type, payload, metadata):
-        LOG.info(_LI("Event '%(event)s' received from %(publisher)s "
-                     "with metadata %(metadata)s") %
+        ctxt.request_id = metadata['message_id']
+        ctxt.project_domain = event_type
+        LOG.info("Event '%(event)s' received from %(publisher)s "
+                 "with metadata %(metadata)s" %
                  dict(event=event_type,
                       publisher=publisher_id,
                       metadata=metadata))
