@@ -19,7 +19,6 @@ import collections
 
 import networkx as nx
 from oslo_config import cfg
-from oslo_config import types
 from oslo_log import log
 
 from watcher.common import utils
@@ -47,12 +46,14 @@ class WeightPlanner(base.BasePlanner):
         super(WeightPlanner, self).__init__(config)
 
     action_weights = {
-        'turn_host_to_acpi_s3_state': 10,
-        'resize': 20,
-        'migrate': 30,
-        'sleep': 40,
+        'nop': 70,
+        'volume_migrate': 60,
         'change_nova_service_state': 50,
-        'nop': 60,
+        'sleep': 40,
+        'migrate': 30,
+        'resize': 20,
+        'turn_host_to_acpi_s3_state': 10,
+        'change_node_power_state': 9,
     }
 
     parallelization = {
@@ -62,22 +63,22 @@ class WeightPlanner(base.BasePlanner):
         'sleep': 1,
         'change_nova_service_state': 1,
         'nop': 1,
+        'change_node_power_state': 2,
+        'volume_migrate': 2
     }
 
     @classmethod
     def get_config_opts(cls):
         return [
-            cfg.Opt(
+            cfg.DictOpt(
                 'weights',
-                type=types.Dict(value_type=types.Integer()),
                 help="These weights are used to schedule the actions. "
                      "Action Plan will be build in accordance with sets of "
                      "actions ordered by descending weights."
                      "Two action types cannot have the same weight. ",
                 default=cls.action_weights),
-            cfg.Opt(
+            cfg.DictOpt(
                 'parallelization',
-                type=types.Dict(value_type=types.Integer()),
                 help="Number of actions to be run in parallel on a per "
                      "action type basis.",
                 default=cls.parallelization),
