@@ -82,6 +82,7 @@ class BaseStrategy(loadable.Loadable):
         self._osc = osc
         self._collector_manager = None
         self._compute_model = None
+        self._storage_model = None
         self._input_parameters = utils.Struct()
         self._audit_scope = None
         self._audit_scope_handler = None
@@ -192,6 +193,27 @@ class BaseStrategy(loadable.Loadable):
 
         return self._compute_model
 
+    @property
+    def storage_model(self):
+        """Cluster data model
+
+        :returns: Cluster data model the strategy is executed on
+        :rtype model: :py:class:`~.ModelRoot` instance
+        """
+        if self._storage_model is None:
+            collector = self.collector_manager.get_cluster_model_collector(
+                'storage', osc=self.osc)
+            self._storage_model = self.audit_scope_handler.get_scoped_model(
+                collector.get_latest_cluster_data_model())
+
+        if not self._storage_model:
+            raise exception.ClusterStateNotDefined()
+
+        if self._storage_model.stale:
+            raise exception.ClusterStateStale()
+
+        return self._storage_model
+
     @classmethod
     def get_schema(cls):
         """Defines a Schema that the input parameters shall comply to
@@ -328,3 +350,19 @@ class WorkloadStabilizationBaseStrategy(BaseStrategy):
     @classmethod
     def get_goal_name(cls):
         return "workload_balancing"
+
+
+@six.add_metaclass(abc.ABCMeta)
+class NoisyNeighborBaseStrategy(BaseStrategy):
+
+    @classmethod
+    def get_goal_name(cls):
+        return "noisy_neighbor"
+
+
+@six.add_metaclass(abc.ABCMeta)
+class SavingEnergyBaseStrategy(BaseStrategy):
+
+    @classmethod
+    def get_goal_name(cls):
+        return "saving_energy"
